Learn R Programming

oscar (version 1.2.1)

cost: Return total cost of model fit based on provided kit/variable costs vector

Description

Return total cost of model fit based on provided kit/variable costs vector

Return total cost of model fit based on provided kit/variable costs vector

Usage

cost(object, k)

# S4 method for oscar cost(object, k)

Value

Numeric value of total feature/kit cost at cardinality 'k'

Numeric value of total feature/kit cost at cardinality 'k'

Arguments

object

Fit oscar S4-object

k

Cardinality 'k' to compute total feature cost at