Return total cost of model fit based on provided kit/variable costs vector
Return total cost of model fit based on provided kit/variable costs vector
cost(object, k)# S4 method for oscar
cost(object, k)
Numeric value of total feature/kit cost at cardinality 'k'
Numeric value of total feature/kit cost at cardinality 'k'
Fit oscar S4-object
Cardinality 'k' to compute total feature cost at